@@ -1,4 +1,6 @@
-from pytest import mark, raises
+from datetime import datetime
+
+from pytest import mark, raises, warns
 
 from fideslang import DataFlow, Dataset, Organization, PrivacyDeclaration, System
 from fideslang.models import (
@@ -8,6 +10,7 @@ from fideslang.models import (
     DatasetField,
     DataUse,
 )
+from tests.conftest import assert_error_message_includes
 
 pytestmark = mark.unit
 
@@ -53,16 +56,25 @@ class TestDataFlow:
         )
 
     def test_dataflow_user_fides_key_no_user_type(self) -> None:
-        with raises(ValueError):
+        with raises(ValueError) as exc:
             assert DataFlow(fides_key="user", type="system")
+        assert_error_message_includes(
+            exc, "The 'user' fides_key is required for, and requires, the type 'user'"
+        )
 
     def test_dataflow_user_type_no_user_fides_key(self) -> None:
-        with raises(ValueError):
+        with raises(ValueError) as exc:
             assert DataFlow(fides_key="test_system_1", type="user")
+        assert_error_message_includes(
+            exc, "The 'user' fides_key is required for, and requires, the type 'user'"
+        )
 
     def test_dataflow_invalid_type(self) -> None:
-        with raises(ValueError):
+        with raises(ValueError) as exc:
             assert DataFlow(fides_key="test_system_1", type="invalid")
+        assert_error_message_includes(
+            exc, "'type' must be one of dataset, system, user"
+        )
 
 
 class TestPrivacyDeclaration:
@@ -83,7 +95,7 @@ class TestSystem:
     # We need to update these tests to assert that the provided args are actually being set
     # as attributes on the System instance that's instantiated.
     def test_system_valid(self) -> None:
-        assert System(
+        system = System(
             description="Test Policy",
             egress=[
                 DataFlow(
@@ -102,8 +114,7 @@ class TestSystem:
             ],
             meta={"some": "meta stuff"},
             name="Test System",
-            organization_fides_key=1,
-            cookies=[{"name": "test_cookie"}],
+            organization_fides_key="1",
             privacy_declarations=[
                 PrivacyDeclaration(
                     data_categories=[],
@@ -112,17 +123,59 @@ class TestSystem:
                     egress=["test_system_2"],
                     ingress=["test_system_3"],
                     name="declaration-name",
-                    cookies=[
-                        {"name": "test_cookie", "path": "/", "domain": "example.com"}
-                    ],
                 )
             ],
             system_type="SYSTEM",
             tags=["some", "tags"],
         )
 
+        assert system.name == "Test System"
+        assert system.fides_key == "test_system"
+        assert system.description == "Test Policy"
+        assert system.egress == [
+            DataFlow(
+                fides_key="test_system_2",
+                type="system",
+                data_categories=[],
+            )
+        ]
+        assert system.ingress == [
+            DataFlow(
+                fides_key="test_system_3",
+                type="system",
+                data_categories=[],
+            )
+        ]
+        assert system.meta == {"some": "meta stuff"}
+        assert system.organization_fides_key == "1"
+        assert system.system_type == "SYSTEM"
+        assert system.tags == ["some", "tags"]
+        assert system.privacy_declarations == [
+            PrivacyDeclaration(
+                name="declaration-name",
+                data_categories=[],
+                data_use="provide",
+                data_subjects=[],
+                dataset_references=None,
+                egress=["test_system_2"],
+                ingress=["test_system_3"],
+                features=[],
+                flexible_legal_basis_for_processing=True,
+                legal_basis_for_processing=None,
+                impact_assessment_location=None,
+                retention_period=None,
+                processes_special_category_data=False,
+                special_category_legal_basis=None,
+                data_shared_with_third_parties=False,
+                third_parties=None,
+                shared_categories=[],
+                cookies=[{"name": "test_cookie"}],
+            )
+        ]
+        assert "cookies" not in system.model_dump()
+
     def test_system_valid_nested_meta(self) -> None:
-        assert System(
+        system = System(
             description="Test Policy",
             egress=[
                 DataFlow(
@@ -152,7 +205,7 @@ class TestSystem:
                 },
             },
             name="Test System",
-            organization_fides_key=1,
+            organization_fides_key="1",
             privacy_declarations=[
                 PrivacyDeclaration(
                     data_categories=[],
@@ -166,6 +219,18 @@ class TestSystem:
             system_type="SYSTEM",
             tags=["some", "tags"],
         )
+        assert system.meta == {
+            "some": "meta stuff",
+            "some": {
+                "nested": "meta stuff",
+                "more nested": "meta stuff",
+            },
+            "some more": {
+                "doubly": {
+                    "nested": "meta stuff",
+                }
+            },
+        }
 
     def test_system_valid_no_meta(self) -> None:
         system = System(
@@ -187,7 +252,7 @@ class TestSystem:
             ],
             # purposefully omitting the `meta` property to ensure it's effectively optional
             name="Test System",
-            organization_fides_key=1,
+            organization_fides_key="1",
             privacy_declarations=[
                 PrivacyDeclaration(
                     data_categories=[],
@@ -209,7 +274,7 @@ class TestSystem:
             fides_key="test_system",
             meta={"some": "meta stuff"},
             name="Test System",
-            organization_fides_key=1,
+            organization_fides_key="1",
             privacy_declarations=[
                 PrivacyDeclaration(
                     data_categories=[],
@@ -223,7 +288,7 @@ class TestSystem:
         )
 
     def test_system_no_egress(self) -> None:
-        with raises(ValueError):
+        with raises(ValueError) as exc:
             assert System(
                 description="Test Policy",
                 fides_key="test_system",
@@ -236,7 +301,7 @@ class TestSystem:
                 ],
                 meta={"some": "meta stuff"},
                 name="Test System",
-                organization_fides_key=1,
+                organization_fides_key="1",
                 privacy_declarations=[
                     PrivacyDeclaration(
                         data_categories=[],
@@ -250,9 +315,13 @@ class TestSystem:
                 system_type="SYSTEM",
                 tags=["some", "tags"],
             )
+        assert_error_message_includes(
+            exc,
+            "PrivacyDeclaration 'declaration-name' defines egress with one or more resources and is applied to the System 'test_system', which does not itself define any egress.",
+        )
 
     def test_system_no_ingress(self) -> None:
-        with raises(ValueError):
+        with raises(ValueError) as exc:
             assert System(
                 description="Test Policy",
                 egress=[
@@ -265,7 +334,7 @@ class TestSystem:
                 fides_key="test_system",
                 meta={"some": "meta stuff"},
                 name="Test System",
-                organization_fides_key=1,
+                organization_fides_key="1",
                 privacy_declarations=[
                     PrivacyDeclaration(
                         data_categories=[],
@@ -279,6 +348,10 @@ class TestSystem:
                 system_type="SYSTEM",
                 tags=["some", "tags"],
             )
+        assert_error_message_includes(
+            exc,
+            "PrivacyDeclaration 'declaration-name' defines ingress with one or more resources and is applied to the System 'test_system', which does not itself define any ingress.",
+        )
 
     def test_system_user_ingress_valid(self) -> None:
         assert System(
@@ -293,7 +366,7 @@ class TestSystem:
             ],
             meta={"some": "meta stuff"},
             name="Test System",
-            organization_fides_key=1,
+            organization_fides_key="1",
             privacy_declarations=[
                 PrivacyDeclaration(
                     data_categories=[],
@@ -308,9 +381,9 @@ class TestSystem:
         )
 
     def test_expanded_system(self):
-        assert System(
+        system = System(
             fides_key="test_system",
-            organization_fides_key=1,
+            organization_fides_key="1",
             tags=["some", "tags"],
             name="Exponential Interactive, Inc d/b/a VDX.tv",
             description="My system test",
@@ -365,12 +438,10 @@ class TestSystem:
                     third_parties="advertising; marketing",
                     shared_categories=[],
                     flexible_legal_basis_for_processing=True,
-                    cookies=[
-                        {"name": "ANON_ID", "path": "/", "domain": "tribalfusion.com"}
-                    ],
                 )
             ],
             vendor_id="gvl.1",
+            vendor_deleted_date=datetime.now(),
             dataset_references=["test_fides_key_dataset"],
             processes_personal_data=True,
             exempt_from_privacy_regulations=False,
@@ -390,18 +461,38 @@ class TestSystem:
             data_security_practices=None,
             cookie_max_age_seconds="31536000",
             uses_cookies=True,
+            cookies=[{"name": "test_cookie"}],
             cookie_refresh=True,
             uses_non_cookie_access=True,
             legitimate_interest_disclosure_url="http://www.example.com/legitimate_interest_disclosure",
             previous_vendor_id="gacp.10",
-            cookies=[
-                {
-                    "name": "COOKIE_ID_EXAMPLE",
-                    "path": "/",
-                    "domain": "example.com/cookie",
-                }
-            ],
         )
+        print(f"dumped={system.model_dump()}")
+        assert "cookies" not in system.model_dump()
+
+    def test_system_cookies_warning(self) -> None:
+
+        with warns(
+            UserWarning,
+            match="The 'cookies' field is deprecated and should not be used. Any value given as this field will be ignored.",
+        ):
+            System(
+                description="Test Policy",
+                fides_key="test_system",
+                name="Test System",
+                organization_fides_key="1",
+                privacy_declarations=[
+                    PrivacyDeclaration(
+                        data_categories=[],
+                        data_subjects=[],
+                        data_use="provide",
+                        name="declaration-name",
+                        cookies=[{"name": "test_cookie"}],
+                    )
+                ],
+                system_type="SYSTEM",
+                cookies=[{"name": "test_cookie"}],
+            )
 
     def test_flexible_legal_basis_default(self):
         pd = PrivacyDeclaration(
@@ -504,4 +595,3 @@ class TestDataset:
 class TestDataUse:
     def test_minimal_data_use(self):
         assert DataUse(fides_key="new_use")
-
